@@ -34,9 +34,6 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه های مشتری که با این برنامه ادغام شده اند را بررسی کنید:",
     "Bookmarklet" : "نشانک",
     "Add to {instanceName}" : "افزودن به {instanceName}",
-    "Clear data" : "داده روشن",
-    "Delete all bookmarks" : "حذف همه نشانک ها",
-    "Do you really want to delete all your bookmarks?" : "آیا واقعاً می خواهید تمام نشانک های خود را حذف کنید؟",
     "Title" : "عنوان",
     "Link" : "Link",
     "Tags" : "برچسب‌ها",
