@@ -45,9 +45,6 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "Skoðaðu einnig úrval þeirra biðlaraforrita sem samþættast þessu forriti:",
     "Bookmarklet" : "Bókamerklingur",
     "Add to {instanceName}" : "Bæta við {instanceName}",
-    "Clear data" : "Hreinsa gögn",
-    "Delete all bookmarks" : "Eyða öllum bókamerkjum",
-    "Do you really want to delete all your bookmarks?" : "Viltu í alvörunni eyða öllum bókmerkjunum þínum?",
     "Title" : "Titill",
     "Link" : "Tengill",
     "Tags" : "Merki",
