@@ -113,10 +113,6 @@ OC.L10N.register(
     "Install on home screen" : "ホーム画面へインストール",
     "Bookmarklet" : "ブックマークレット",
     "Add to {instanceName}" : "{instanceName}に追加",
-    "Clear data" : "データを消去",
-    "Permanently remove all bookmarks from your account." : "すべてのブックマークを永久にあなたのアカウントから削除します。",
-    "Delete all bookmarks" : "すべてのブックマークを削除",
-    "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
     "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
     "Title" : "タイトル",
     "Link" : "リンク",
