@@ -30,9 +30,6 @@ OC.L10N.register(
     "Export" : "내보내기",
     "Bookmarklet" : "북마크릿",
     "Add to {instanceName}" : "{instanceName}에 더하기",
-    "Clear data" : "데이터 지우기",
-    "Delete all bookmarks" : "모든 북마크 삭제",
-    "Do you really want to delete all your bookmarks?" : "모든 북마크를 삭제하시겠습니까?",
     "Title" : "직위",
     "Link" : "링크",
     "Tags" : "태그",
