@@ -55,9 +55,6 @@ OC.L10N.register(
     "Export" : "Eksportuoti",
     "Client apps" : "Kliento programėlės",
     "Add to {instanceName}" : "Pridėti į {instanceName}",
-    "Clear data" : "Išvalyti duomenis",
-    "Delete all bookmarks" : "Ištrinti visą adresyną",
-    "Do you really want to delete all your bookmarks?" : "Ar tikrai norite ištrinti visus savo adresyno įrašus?",
     "Title" : "Pareigos",
     "Link" : "Nuoroda",
     "Tags" : "Žymės",
