@@ -120,10 +120,6 @@ OC.L10N.register(
     "Install on home screen" : "Installa in s'ischermada printzipale",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Agiunghe a {instanceName}",
-    "Clear data" : "Lìmpia is datos",
-    "Permanently remove all bookmarks from your account." : "Boga totu is signalibros de su contu tuo de su totu.",
-    "Delete all bookmarks" : "Cantzella totu is signalibros",
-    "Do you really want to delete all your bookmarks?" : "A beru cheres cantzellare totu is signalibros?",
     "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
     "Title" : "Tìtulu",
     "Link" : "Ligòngiu",
