@@ -45,9 +45,6 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "Такође погледајте и колекцију клијентских апликација које се интегришу са овом апликацијом:",
     "Bookmarklet" : "Забележник",
     "Add to {instanceName}" : "Додај на {instanceName} ",
-    "Clear data" : "Очисти податке",
-    "Delete all bookmarks" : "Обриши све обележиваче",
-    "Do you really want to delete all your bookmarks?" : "Заиста желите да обришете све своје обележиваче?",
     "Title" : "Наслов",
     "Link" : "Веза",
     "Tags" : "Ознаке",
