@@ -120,10 +120,6 @@ OC.L10N.register(
     "Install on home screen" : "Installera på hemskärmen",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Lägg till {instanceName}",
-    "Clear data" : "Rensa data",
-    "Permanently remove all bookmarks from your account." : "Ta bort alla bokmärken från ditt konto permanent.",
-    "Delete all bookmarks" : "Ta bort alla bokmärken",
-    "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
     "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
     "Title" : "Titel",
     "Link" : "Länk",
