@@ -132,8 +132,9 @@ OC.L10N.register(
     "Export" : "匯出",
     "Archive path" : "封存路徑",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入要儲存書籤檔案的資料夾路徑。",
-    "Backup path" : "備份路徑",
-    "Enter the path of a folder in your Files where your bookmarks backups will be stored." : "在「檔案」中輸入要儲存書籤備份的資料夾路徑。",
+    "Backups" : "備份",
+    "Enable bookmarks backups" : "啟用書籤備份",
+    "Enter the path of a folder in your Files where backups will be stored." : "輸入在您「檔案」中要儲存備份的資料夾路徑。",
     "Client apps" : "客戶端應用程式",
     "Also check out the collection of client apps that integrate with this app: " : "還要檢查與此應用程式整合的客戶端應用程式集合：",
     "Install web app on device" : "在裝置上安裝網路應用程式",
@@ -142,6 +143,7 @@ OC.L10N.register(
     "Bookmarklet" : "書籤",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "將這個拖曳到您的瀏覽器書籤中，並點擊它以快速將網頁加入書籤。",
     "Add to {instanceName}" : "新增到 {instanceName}",
+    "Backup path" : "備份路徑",
     "Please select \"Add to home screen\" in your browser menu" : "請在您的瀏覽器選單中選取「新增至主畫面」",
     "Title" : "標題",
     "Link" : "連結",
