@@ -7,9 +7,9 @@
 
 namespace OCA\Bookmarks\Service;
 
-use andreskrey\Readability\Configuration;
-use andreskrey\Readability\ParseException;
-use andreskrey\Readability\Readability;
+use marcelklehr\Readability\Configuration;
+use marcelklehr\Readability\ParseException;
+use marcelklehr\Readability\Readability;
 use Exception;
 use GuzzleHttp\Client;
 use GuzzleHttp\Psr7\Response;
@@ -93,6 +93,7 @@ class CrawlService {
 				'connect_timeout' => self::CONNECT_TIMEOUT,
 				'timeout' => self::TIMEOUT,
 				'read_timeout' => self::READ_TIMEOUT,
+				'http_errors' => false
 			]);
 			$available = $resp ? $resp->getStatusCode() !== 404 : false;
 		} catch (Exception $e) {
