@@ -7,11 +7,13 @@
 
 namespace OCA\Bookmarks\Service;
 
+use DateTime;
 use OCA\Bookmarks\Db\FolderMapper;
 use OCA\Bookmarks\Db\Types;
 use OCP\IDBConnection;
 
 class LockManager {
+	public const TIMEOUT = 60 * 30; // half an hour
 
 	/**
 	 * @var IDBConnection
@@ -33,9 +35,10 @@ class LockManager {
 	 */
 	public function setLock(string $userId, bool $locked): void {
 		$this->folderMapper->findRootFolder($userId);
+		$value = $locked ? new DateTime() : new DateTime('@0'); // now or begin of UNIX time
 		$qb = $this->db->getQueryBuilder();
 		$qb->update('bookmarks_root_folders')
-			->set('locked', $qb->createNamedParameter($locked, Types::BOOLEAN))
+			->set('locked_time', $qb->createNamedParameter($value, Types::DATETIME))
 			->where($qb->expr()->eq('user_id', $qb->createNamedParameter($userId)))
 			->execute();
 	}
@@ -47,11 +50,19 @@ class LockManager {
 	public function getLock(string $userId): bool {
 		$this->folderMapper->findRootFolder($userId);
 		$qb = $this->db->getQueryBuilder();
-		$locked = $qb->select('locked')
+		$lockedAt = $qb->select('locked_time')
 			->from('bookmarks_root_folders')
 			->where($qb->expr()->eq('user_id', $qb->createNamedParameter($userId)))
 			->execute()
 			->fetch(\PDO::FETCH_COLUMN);
-		return (bool) $locked;
+		if ($lockedAt === null) {
+			return false;
+		}
+		try {
+			$dateTime = new DateTime($lockedAt);
+		} catch (\Exception $e) {
+			return false;
+		}
+		return time() - $dateTime->getTimestamp() < self::TIMEOUT;
 	}
 }
